@@ -6,6 +6,7 @@ from os.path import join
 import pytest
 from hdx.hdx_configuration import Configuration
 from hdx.hdx_locations import Locations
+from hdx.location.country import Country
 
 
 @pytest.fixture(scope='session')
@@ -13,7 +14,8 @@ def configuration():
     Configuration._create(hdx_read_only=True, hdx_site='prod', user_agent='test',
                           project_config_yaml=join('tests', 'config', 'project_configuration.yml'))
     Locations.set_validlocations(
-        [{'name': 'afg', 'title': 'Afghanistan'}, {'name': 'pse', 'title': 'State of Palestine'}])
+        [{'name': 'afg', 'title': 'Afghanistan'}, {'name': 'phl', 'title': 'Philippines'}, {'name': 'pse', 'title': 'State of Palestine'}])
+    Country.countriesdata(use_live=False)
     return Configuration.read()
 
 
